List of PTMs
============

Below is a list of post-translational modifications (PTMs) that are currently supported. Additional ones may
be considered as well, please open an issue detailing the significance of the request.

.. list-table::
   :header-rows: 1
   :widths: 15 15 15 30 25


   * - original
     - modified
     - name
     - pubchem
     - chemspider
   * - ARG
     - RCI
     - citrulline
     - `9750 <https://pubchem.ncbi.nlm.nih.gov/compound/9750>`_
     - `9367 <https://www.chemspider.com/Chemical-Structure.9367.html>`_
   * - ARG
     - RSM
     - symmetric-dimethylarginine (0)
     - `169148 <https://pubchem.ncbi.nlm.nih.gov/compound/169148>`_
     - `147942 <https://www.chemspider.com/Chemical-Structure.147942.html>`_
   * - ARG
     - RMS
     - symmetric-dimethylarginine (+1)
     - `25320698 <https://pubchem.ncbi.nlm.nih.gov/compound/25320698>`_
     - `21239047 <https://www.chemspider.com/Chemical-Structure.21239047.html>`_
   * - ARG
     - RAM
     - asymmetric-dimethylarginine (0)
     - `123831 <https://pubchem.ncbi.nlm.nih.gov/compound/123831>`_
     - `110375 <https://www.chemspider.com/Chemical-Structure.110375.html>`_
   * - ARG
     - RMA
     - asymmetric-dimethylarginine (+1)
     -
     -
   * - ARG
     - RMN
     - omega-N-methylarginine (0)
     - `132862 <https://pubchem.ncbi.nlm.nih.gov/compound/132862>`_
     - `117259 <https://www.chemspider.com/Chemical-Structure.117259.html>`_
   * - ARG
     - RMC
     - omega-N-methylarginine
     -
     -
   * - ARG
     - R0P
     -
     -
     -
   * - ARG
     - GSA
     - glutamic semialdehyde
     - `193305 <https://pubchem.ncbi.nlm.nih.gov/compound/193305>`_
     - `167744 <https://www.chemspider.com/Chemical-Structure.167744.html>`_
   * - ARG
     - R1P
     - phosphoarginine (-1)
     -
     -
   * - ASN
     - N3H
     - 3-hydroxyasparagine (R)
     - `4471902 <https://pubchem.ncbi.nlm.nih.gov/compound/4471902>`_
     - `3670287 <https://www.chemspider.com/Chemical-Structure.3670287.html>`_
   * - ASN
     - NH3
     - 3-hydroxyasparagine (S)
     - `15991574 <https://pubchem.ncbi.nlm.nih.gov/compound/15991574>`_
     - `13122509 <https://www.chemspider.com/Chemical-Structure.13122509.html>`_
   * - ASN
     - NNG
     - N-acetylglucosamine
     - `1738118 <https://pubchem.ncbi.nlm.nih.gov/compound/1738118>`_
     - `1376695 <https://www.chemspider.com/Chemical-Structure.1376695.html>`_
   * - ASN
     - NME
     - N4-methylasparagine
     - `325695 <https://pubchem.ncbi.nlm.nih.gov/compound/325695>`_
     - `288387 <https://www.chemspider.com/Chemical-Structure.288387.html>`_
   * - ASN
     - ASP
     - aspartic acid (-1)
     -
     -
   * - ASN
     - ASPH
     -
     -
     -
   * - ASP
     - DN3
     - 3-hydroxyaspartate (0, R)
     - `11788378 <https://pubchem.ncbi.nlm.nih.gov/compound/11788378>`_
     - `9963052 <https://www.chemspider.com/Chemical-Structure.9963052.html>`_
   * - ASP
     - D3N
     - 3-hydroxyaspartate (0, S)
     - `5425 <https://pubchem.ncbi.nlm.nih.gov/compound/5425>`_
     - `5232 <https://www.chemspider.com/Chemical-Structure.5232.html>`_
   * - ASP
     - D3H
     - 3-hydroxyaspartate (-1, S)
     -
     -
   * - ASP
     - DH3
     - 3-hydroxyaspartate (-1, R)
     -
     -
   * - ASP
     - DMA
     - aspartate methyl ester
     - `97368 <https://pubchem.ncbi.nlm.nih.gov/compound/97368>`_
     - `87886 <https://www.chemspider.com/Chemical-Structure.87886.html>`_
   * - ASP
     - D1P
     - phosphoaspartate (-1)
     -
     -
   * - ASP
     - D2P
     - phosphoaspartate (-2)
     -
     -
   * - CYS
     - CSE
     - cysteic acid
     - `25701 <https://pubchem.ncbi.nlm.nih.gov/compound/25701>`_
     - `23942 <https://www.chemspider.com/Chemical-Structure.23942.html>`_
   * - CYS
     - CAM
     - S-carbamoyl-cysteine
     - `90546 <https://pubchem.ncbi.nlm.nih.gov/compound/90546>`_
     - `81753 <https://www.chemspider.com/Chemical-Structure.81753.html>`_
   * - CYS
     - CSA
     - cysteine sulfinic acid
     - `109 <https://pubchem.ncbi.nlm.nih.gov/compound/109>`_
     - `107 <https://www.chemspider.com/Chemical-Structure.107.html>`_
   * - CYS
     - CYH
     - cysteine sulfenic acid
     - `165339 <https://pubchem.ncbi.nlm.nih.gov/compound/165339>`_
     - `144942 <https://www.chemspider.com/Chemical-Structure.144942.html>`_
   * - CYS
     - CSN
     - S-nitrosocysteine
     - `9793848 <https://pubchem.ncbi.nlm.nih.gov/compound/9793848>`_
     - `7969615 <https://www.chemspider.com/Chemical-Structure.7969615.html>`_
   * - CYS
     - CYM
     - S-methylcysteine
     - `24417 <https://pubchem.ncbi.nlm.nih.gov/compound/24417>`_
     - `22826 <https://www.chemspider.com/Chemical-Structure.22826.html>`_
   * - GLN
     - Q4H
     - 4-hydroxyglutamine (R)
     - `22621570 <https://pubchem.ncbi.nlm.nih.gov/compound/22621570>`_
     - `13488647 <https://www.chemspider.com/Chemical-Structure.13488647.html>`_
   * - GLN
     - QH4
     - 4-hydroxyglutamine (S)
     - `54409926 <https://pubchem.ncbi.nlm.nih.gov/compound/54409926>`_
     - `61327209 <https://www.chemspider.com/Chemical-Structure.61327209.html>`_
   * - GLN
     - QME
     - N5-methylglutamine
     - `439925 <https://pubchem.ncbi.nlm.nih.gov/compound/439925>`_
     - `388957 <https://www.chemspider.com/Chemical-Structure.388957.html>`_
   * - GLN
     - GLU
     - glutamic acid (-1)
     -
     -
   * - GLN
     - GLUH
     -
     -
     -
   * - GLU
     - ECA
     - 4-carboxyglutamate (-2)
     -
     -
   * - GLU
     - ECN
     - 4-carboxyglutamate (-1)
     -
     -
   * - GLU
     - EME
     - glutamate methyl ester
     - `68662 <https://pubchem.ncbi.nlm.nih.gov/compound/68662>`_
     - `61916 <https://www.chemspider.com/Chemical-Structure.61916.html>`_
   * - HIS
     - H2X
     - 2-oxo-histidine
     - `127761 <https://pubchem.ncbi.nlm.nih.gov/compound/127761>`_
     - `113326 <https://www.chemspider.com/Chemical-Structure.113326.html>`_
   * - HIS
     - H3M
     - 3-methylhistidine (0)
     - `64969 <https://pubchem.ncbi.nlm.nih.gov/compound/64969>`_
     - `58494 <https://www.chemspider.com/Chemical-Structure.58494.html>`_
   * - HIS
     - H3C
     - 3-methylhistidine (+1)
     -
     -
   * - HIS
     - H1C
     - 1-methylhistidine (+1)
     -
     -
   * - HIS
     - H1M
     - 1-methylhistidine (0)
     - `92105 <https://pubchem.ncbi.nlm.nih.gov/compound/92105>`_
     - `83153 <https://www.chemspider.com/Chemical-Structure.83153.html>`_
   * - HIS
     - H32
     - 3-phosphohistidine (-2)
     -
     -
   * - HIS
     - H31
     - 3-phosphohistidine (-1)
     -
     -
   * - HIS
     - H12
     - 1-phosphohistidine (-2)
     -
     -
   * - HIS
     - H11
     - 1-phosphohistidine (-1)
     -
     -
   * - HIS
     - ASP
     - aspartic acid (-1)
     -
     -
   * - HIS
     - ASPH
     -
     -
     -
   * - HIS
     - ASN
     - asparagine
     - `6267 <https://pubchem.ncbi.nlm.nih.gov/compound/6267>`_
     - `6031 <https://www.chemspider.com/Chemical-Structure.6031.html>`_
   * - LEU
     - L3H
     - 3-hydroxyleucine (R)
     -
     -
   * - LEU
     - LH3
     - 3-hydroxyleucine (S)
     - `6994741 <https://pubchem.ncbi.nlm.nih.gov/compound/6994741>`_
     - `5362730 <https://www.chemspider.com/Chemical-Structure.5362730.html>`_
   * - LEU
     - L4H
     - 4-hydroxyleucine
     - `21087467 <https://pubchem.ncbi.nlm.nih.gov/compound/21087467>`_
     - `19895986 <https://www.chemspider.com/Chemical-Structure.19895986.html>`_
   * - LEU
     - LH5
     - 5-hydroxyleucine (S)
     - `15927962 <https://pubchem.ncbi.nlm.nih.gov/compound/15927962>`_
     - `32970047 <https://www.chemspider.com/Chemical-Structure.32970047.html>`_
   * - LEU
     - L5H
     - 5-hydroxyleucine (R)
     - `15927964 <https://pubchem.ncbi.nlm.nih.gov/compound/15927964>`_
     - `32970048 <https://www.chemspider.com/Chemical-Structure.32970048.html>`_
   * - LEU
     - LNO
     - norleucine
     - `21236 <https://pubchem.ncbi.nlm.nih.gov/compound/21236>`_
     - `19964 <https://www.chemspider.com/Chemical-Structure.19964.html>`_
   * - LYS
     - KAL
     - allysine
     - `160603 <https://pubchem.ncbi.nlm.nih.gov/compound/160603>`_
     - `141126 <https://www.chemspider.com/Chemical-Structure.141126.html>`_
   * - LYS
     - KAM
     - homocitrulline
     - `65072 <https://pubchem.ncbi.nlm.nih.gov/compound/65072>`_
     - `58582 <https://www.chemspider.com/Chemical-Structure.58582.html>`_
   * - LYS
     - KH5
     - 5-hydroxylysine (0, R)
     - `3032849 <https://pubchem.ncbi.nlm.nih.gov/compound/3032849>`_
     - `2297721 <https://www.chemspider.com/Chemical-Structure.2297721.html>`_
   * - LYS
     - K5H
     - 5-hydroxylysine (0, S)
     -
     -
   * - LYS
     - KHP
     - 5-hydroxylysine (+1, S)
     -
     -
   * - LYS
     - KPH
     - 5-hydroxylysine (+1, R)
     -
     -
   * - LYS
     - KCA
     - carboxylysine (-1)
     -
     -
   * - LYS
     - KCN
     - carboxylysine (0)
     -
     -
   * - LYS
     - KHR
     - hypusine (R)
     - `10922432 <https://pubchem.ncbi.nlm.nih.gov/compound/10922432>`_
     - `9097677 <https://www.chemspider.com/Chemical-Structure.9097677.html>`_
   * - LYS
     - KHS
     - hypusine (S)
     -
     -
   * - LYS
     - KLA
     - alpha-lysyllysine
     -
     -
   * - LYS
     - KLB
     - beta-lysyllysine
     -
     -
   * - LYS
     - KAC
     - N-acetyllysine
     - `92907 <https://pubchem.ncbi.nlm.nih.gov/compound/92907>`_
     - `83869 <https://www.chemspider.com/Chemical-Structure.83869.html>`_
   * - LYS
     - K3C
     - N6,N6,N6-trimethyllysine
     - `440121 <https://pubchem.ncbi.nlm.nih.gov/compound/440121>`_
     - `389121 <https://www.chemspider.com/Chemical-Structure.389121.html>`_
   * - LYS
     - K2M
     - N6,N6-dimethyllysine (0)
     - `193344 <https://pubchem.ncbi.nlm.nih.gov/compound/193344>`_
     - `167778 <https://www.chemspider.com/Chemical-Structure.167778.html>`_
   * - LYS
     - KMN
     - methyllysine (0)
     - `541646 <https://pubchem.ncbi.nlm.nih.gov/compound/541646>`_
     - `471673 <https://www.chemspider.com/Chemical-Structure.471673.html>`_
   * - LYS
     - KMC
     - N6-methyllysine (+1)
     -
     -
   * - LYS
     - K2C
     - N6,N6-dimethyllysine (+1)
     -
     -
   * - LYS
     - K1P
     - phospholysine (-1)
     -
     -
   * - LYS
     - LNO
     - norleucine
     - `21236 <https://pubchem.ncbi.nlm.nih.gov/compound/21236>`_
     - `19964 <https://www.chemspider.com/Chemical-Structure.19964.html>`_
   * - LYS
     - K2P
     - phospholysine (-2)
     -
     -
   * - MET
     - MES
     - methionine sulfone
     - `445282 <https://pubchem.ncbi.nlm.nih.gov/compound/445282>`_
     - `392966 <https://www.chemspider.com/Chemical-Structure.392966.html>`_
   * - MET
     - MXS
     - methionine sulfoxide (S)
     - `158980 <https://pubchem.ncbi.nlm.nih.gov/compound/158980>`_
     - `139840 <https://www.chemspider.com/Chemical-Structure.139840.html>`_
   * - MET
     - MSX
     - methionine sulfoxide (R)
     - `148508 <https://pubchem.ncbi.nlm.nih.gov/compound/148508>`_
     - `130911 <https://www.chemspider.com/Chemical-Structure.130911.html>`_
   * - MET
     - LNO
     - norleucine
     - `21236 <https://pubchem.ncbi.nlm.nih.gov/compound/21236>`_
     - `19964 <https://www.chemspider.com/Chemical-Structure.19964.html>`_
   * - PHE
     - F23
     -
     -
     -
   * - PHE
     - F2H
     - 2-hydroxyphenylalanine
     - `91482 <https://pubchem.ncbi.nlm.nih.gov/compound/91482>`_
     - `82607 <https://www.chemspider.com/Chemical-Structure.82607.html>`_
   * - PHE
     - F3H
     - 3-hydroxyphenylalanine
     - `6950578 <https://pubchem.ncbi.nlm.nih.gov/compound/6950578>`_
     - `5323512 <https://www.chemspider.com/Chemical-Structure.5323512.html>`_
   * - PHE
     - TYR
     - tyrosine
     - `6057 <https://pubchem.ncbi.nlm.nih.gov/compound/6057>`_
     - `5833 <https://www.chemspider.com/Chemical-Structure.5833.html>`_
   * - PRO
     - PGA
     - 3-hydroxyproline (S)
     -
     -
   * - PRO
     - PHH
     - 3,4-dihydroxyproline
     - `6454515 <https://pubchem.ncbi.nlm.nih.gov/compound/6454515>`_
     - `4956829 <https://www.chemspider.com/Chemical-Structure.4956829.html>`_
   * - PRO
     - HY2
     - 4-hydroxyproline (R)
     - `5810 <https://pubchem.ncbi.nlm.nih.gov/compound/5810>`_
     - `5605 <https://www.chemspider.com/Chemical-Structure.5605.html>`_
   * - PRO
     - PH3
     - 3-hydroxyproline (R)
     -
     -
   * - PRO
     - P3H
     - 3-hydroxyproline (S)
     - `150779 <https://pubchem.ncbi.nlm.nih.gov/compound/150779>`_
     - `132893 <https://www.chemspider.com/Chemical-Structure.132893.html>`_
   * - PRO
     - HYP
     - 4-hydroxyproline (S)
     -
     -
   * - PRO
     - P5H
     - 5-hydroxyproline (S)
     - `14325405 <https://pubchem.ncbi.nlm.nih.gov/compound/14325405>`_
     - `25943482 <https://www.chemspider.com/Chemical-Structure.25943482.html>`_
   * - PRO
     - PH5
     - 5-hydroxyproline (R)
     - `6338400 <https://pubchem.ncbi.nlm.nih.gov/compound/6338400>`_
     - `32989511 <https://www.chemspider.com/Chemical-Structure.32989511.html>`_
   * - PRO
     - GSA
     - glutamic semialdehyde
     - `193305 <https://pubchem.ncbi.nlm.nih.gov/compound/193305>`_
     - `167744 <https://www.chemspider.com/Chemical-Structure.167744.html>`_
   * - SER
     - SOG
     - serine-O-acetylglucosamine
     -
     -
   * - SER
     - S1P
     - phosphoserine (-1)
     -
     -
   * - SER
     - SDH
     - dehydroalanine
     - `123991 <https://pubchem.ncbi.nlm.nih.gov/compound/123991>`_
     - `110510 <https://www.chemspider.com/Chemical-Structure.110510.html>`_
   * - SER
     - S2P
     - phosphoserine (-2)
     -
     -
   * - THR
     - TOX
     - 2-amino-3-ketobutyric acid
     - `440033 <https://pubchem.ncbi.nlm.nih.gov/compound/440033>`_
     -
   * - THR
     - TOG
     - threonine-O-acetylglucosamine
     -
     -
   * - THR
     - T1P
     - phosphothreonine (-1)
     -
     -
   * - THR
     - TDH
     - 2,3-didehydrobutyrine
     - `3082167 <https://pubchem.ncbi.nlm.nih.gov/compound/3082167>`_
     -
   * - THR
     - T2P
     - phosphothreonine (-2)
     -
     -
   * - TRP
     - W2H
     - 2-hydroxytryptophan
     - `17754204 <https://pubchem.ncbi.nlm.nih.gov/compound/17754204>`_
     - `16744237 <https://www.chemspider.com/Chemical-Structure.16744237.html>`_
   * - TRP
     - W4H
     - 4-hydroxytryptophan
     - `589768 <https://pubchem.ncbi.nlm.nih.gov/compound/589768>`_
     - `512674 <https://www.chemspider.com/Chemical-Structure.512674.html>`_
   * - TRP
     - W5H
     - 5-hydroxytryptophan
     - `144 <https://pubchem.ncbi.nlm.nih.gov/compound/144>`_
     - `141 <https://www.chemspider.com/Chemical-Structure.141.html>`_
   * - TRP
     - W6H
     - 6-hydroxytryptophan
     - `49867758 <https://pubchem.ncbi.nlm.nih.gov/compound/49867758>`_
     - `25058065 <https://www.chemspider.com/Chemical-Structure.25058065.html>`_
   * - TRP
     - W7H
     - 7-hydroxytryptophan
     - `2763071 <https://pubchem.ncbi.nlm.nih.gov/compound/2763071>`_
     - `2043769 <https://www.chemspider.com/Chemical-Structure.2043769.html>`_
   * - TRP
     - WNI
     - 6-nitrotryptophan
     - `3246256 <https://pubchem.ncbi.nlm.nih.gov/compound/3246256>`_
     - `2496980 <https://www.chemspider.com/Chemical-Structure.2496980.html>`_
   * - TRP
     - WBR
     - 6-bromotryptophan
     - `9856996 <https://pubchem.ncbi.nlm.nih.gov/compound/9856996>`_
     - `8032696 <https://www.chemspider.com/Chemical-Structure.8032696.html>`_
   * - TRP
     - WKF
     - formyl-kynurenine
     - `910 <https://pubchem.ncbi.nlm.nih.gov/compound/910>`_
     - `886 <https://www.chemspider.com/Chemical-Structure.886.html>`_
   * - TRP
     - WKH
     - 3-hydroxykynurenine
     - `89 <https://pubchem.ncbi.nlm.nih.gov/compound/89>`_
     - `87 <https://www.chemspider.com/Chemical-Structure.87.html>`_
   * - TRP
     - WKY
     - kynurenine
     - `161166 <https://pubchem.ncbi.nlm.nih.gov/compound/161166>`_
     - `141580 <https://www.chemspider.com/Chemical-Structure.141580.html>`_
   * - TYR
     - YSU
     - sulfotyrosine
     - `514186 <https://pubchem.ncbi.nlm.nih.gov/compound/514186>`_
     - `448617 <https://www.chemspider.com/Chemical-Structure.448617.html>`_
   * - TYR
     - HTY
     - 3,4-dihydroxyphenylalanine
     - `6047 <https://pubchem.ncbi.nlm.nih.gov/compound/6047>`_
     - `5824 <https://www.chemspider.com/Chemical-Structure.5824.html>`_
   * - TYR
     - YNB
     - nitrotyrosine (neutral) old
     -
     -
   * - TYR
     - YNN
     - nitrotyrosine (0) pre-revised
     - `65124 <https://pubchem.ncbi.nlm.nih.gov/compound/65124>`_
     - `58633 <https://www.chemspider.com/Chemical-Structure.58633.html>`_
   * - TYR
     - YNI
     - nitrotyrosine (-1)
     -
     -
   * - TYR
     - Y1P
     - phosphotyrosine (-1)
     -
     -
   * - TYR
     - YCH
     - chlorotyrosine
     - `110992 <https://pubchem.ncbi.nlm.nih.gov/compound/110992>`_
     - `99636 <https://www.chemspider.com/Chemical-Structure.99636.html>`_
   * - TYR
     - Y2P
     - phosphotyrosine (-2)
     -
     -
   * - VAL
     - V3H
     - 3-hydroxyvaline
     - `192763 <https://pubchem.ncbi.nlm.nih.gov/compound/192763>`_
     - `167279 <https://www.chemspider.com/Chemical-Structure.167279.html>`_
